:mod:`art.classifiers`
======================
.. automodule:: art.classifiers

Keras Wrapper
-------------
.. autoclass:: KerasClassifier
   :members:
   :special-members:

MXNet Wrapper
-------------
.. autoclass:: MXClassifier
   :members:
   :special-members:

PyTorch Wrapper
---------------
.. autoclass:: PyTorchClassifier
   :members:
   :special-members:

Tensorflow Wrapper
------------------
.. autoclass:: TFClassifier
   :members:
   :special-members:

Ensemble Wrapper
----------------
.. autoclass:: EnsembleClassifier
   :members:
   :special-members:

Base Class
----------
.. autoclass:: Classifier
   :members:
